#include "BMP280Sensor.h"

// Constructor sets the I2C address
BMP280Sensor::BMP280Sensor(uint8_t address) {
    i2c_address = address; // Set the i2c_address from the base class
}

// Initialize the BMP280 sensor
void BMP280Sensor::init() {
    // Begin communication with the sensor
    bool ok = bmp280.begin(i2c_address);

    if (!ok) {
        // Handle initialization error
        // In a real application, you might want to log this error or retry
    }

    // Set the sensor to forced mode with basic sampling settings
    bmp280.setSampling(Adafruit_BME280::MODE_FORCED,
                       Adafruit_BME280::SAMPLING_X1, // temperature
                       Adafruit_BME280::SAMPLING_X1, // pressure
                       Adafruit_BME280::SAMPLING_X1, // humidity
                       Adafruit_BME280::FILTER_OFF);
}

// Return the name of the sensor
std::string BMP280Sensor::getName() const {
    return "BMP280";
}

// Return a list of features the sensor can read
std::vector<ReadingType> BMP280Sensor::getFeatures() const {
    return {ReadingType::Temperature, ReadingType::Humidity, ReadingType::Pressure, ReadingType::Altitude};
}

// Read the value of a specified feature
float BMP280Sensor::readValue(ReadingType feature) {
    // Take a measurement in forced mode
    bmp280.takeForcedMeasurement();

    switch (feature) {
        case ReadingType::Temperature:
            return bmp280.readTemperature();
        case ReadingType::Humidity:
            return bmp280.readHumidity();
        case ReadingType::Pressure:
            return bmp280.readPressure() / 100.0F; // Convert to hPa
        case ReadingType::Altitude:
            return bmp280.readAltitude(SEALEVELPRESSURE_HPA);
        default:
            return NAN; // Return NaN for unsupported features
    }
}
