#include "CCS811Sensor.h"

CCS811Sensor::CCS811Sensor(uint8_t wakePin)
  : wakePin_(wakePin), ccs811_(wakePin), temperaturePtr_(nullptr), humidityPtr_(nullptr) {
  i2c_address = 0x5A; // Default I2C address for CCS811
}

void CCS811Sensor::init() {
  init(nullptr, nullptr);
}

void CCS811Sensor::init(double* temperature, double* humidity) {
  bool ok = ccs811_.begin();
  if (!ok) {
    // Serial.println("CCS811 initialization failed");
    return;
  }

  ok = ccs811_.start(CCS811_MODE_1SEC);
  if (!ok) {
    // Serial.println("CCS811 start failed");
    return;
  }

  temperaturePtr_ = temperature;
  humidityPtr_ = humidity;
}

std::string CCS811Sensor::getName() const {
  return "CCS811";
}

std::vector<ReadingType> CCS811Sensor::getFeatures() const {
  return {ReadingType::eCO2, ReadingType::eTVOC, ReadingType::ErrorStatus};
}

float CCS811Sensor::readValue(ReadingType feature) {
  uint16_t eco2, etvoc, errstat, raw;
  if (temperaturePtr_ && humidityPtr_) {
    ccs811_.set_envdata(*temperaturePtr_, *humidityPtr_);
  }
  ccs811_.read(&eco2, &etvoc, &errstat, &raw);

  switch (feature) {
  case ReadingType::eCO2:
    return static_cast<float>(eco2);
  case ReadingType::eTVOC:
    return static_cast<float>(etvoc);
  case ReadingType::ErrorStatus:
    return static_cast<float>(errstat);
  default:
    return NAN; // Return NaN for unsupported features
  }
}
